<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Retorn a la interfície gràfica completa',
	'access_mode_texte' => 'Mostrar la interfície en mode text simplificada',
	'admin_debug' => 'depuració',
	'admin_modifier_article' => 'Modificar aquest article',
	'admin_modifier_auteur' => 'Modificar aquest/a autor/a',
	'admin_modifier_breve' => 'Modificar aquesta breu',
	'admin_modifier_mot' => 'Modificar aquesta paraula clau',
	'admin_modifier_rubrique' => 'Modificar aquesta secció',
	'admin_recalculer' => 'Recarregar aquesta pàgina',
	'afficher_calendrier' => 'Mostrar el calendari',
	'afficher_trad' => 'visualitzar les traduccions',
	'alerte_maj_impossible' => '<b>Alerta !</b> L’actualització de la base de dades SQL cap a la versió @version@ és impossible. Pot ser que tingueu un problema de drets de modificació de la base de dades. Si us plau, contacteu amb el vostre proveïdor d’hostatge.',
	'alerte_modif_info_concourante' => 'ATENCIÓ: Aquesta informació s’ha modificat per una altra banda. El valor actual és:',
	'analyse_xml' => 'Anàlisi XML',
	'annuler' => 'Anul·lar',
	'antispam_champ_vide' => 'Si us plau, deixeu aquest camp buit:',
	'articles_recents' => 'Els articles més recents',
	'avis_1_erreur_saisie' => 'Hi ha una errada en la vostra entrada, comprobe les dades.', # MODIF
	'avis_archive_incorrect' => 'el fitxer no és pas un fitxer SPIP',
	'avis_archive_invalide' => 'el fitxer no és pas vàlid',
	'avis_attention' => 'ATENCIÓ !',
	'avis_champ_incorrect_type_objet' => 'Nom de camp incorrecte @name@ per objecte del tipus @type@',
	'avis_colonne_inexistante' => 'La columna @col@ no existeix pas',
	'avis_erreur' => 'Error: veure ací baix',
	'avis_erreur_connexion' => 'Error de connexió',
	'avis_erreur_cookie' => 'problema de galeta (cookie)',
	'avis_erreur_fonction_contexte' => 'Error de programació. Aquesta funció no ha de ser cridada en aquest context.',
	'avis_erreur_mysql' => 'Error SQL',
	'avis_erreur_sauvegarde' => ' Error al desar (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Problema d’accés a l’espai privat',
	'avis_nb_erreurs_saisie' => 'Hi ha @nb@ errors en la vostra entrada, comprobe les dades.',

	// B
	'barre_a_accent_grave' => 'Inserir una A majúscula amb accent greu',
	'barre_aide' => 'Utilitzi les dreceres tipogràfiques per enriquir la seva compaginació',
	'barre_e_accent_aigu' => 'Inserir una E majúscula amb accent agut',
	'barre_eo' => 'Inserir una E dins la O',
	'barre_eo_maj' => 'Inserir una E dins l’O majúscula',
	'barre_euro' => 'Inserir el símbol €',
	'barre_gras' => 'Posar en {{negreta}}',
	'barre_guillemets' => 'Posar entre « cometes franceses » ',
	'barre_guillemets_simples' => 'Posar entre "cometes"',
	'barre_intertitre' => 'Transformar en {{{subtítol}}}',
	'barre_italic' => 'Posar en {itàlica}',
	'barre_lien' => 'Transformar en [enllaç->http://...]',
	'barre_lien_input' => 'Indiqueu l’adreça del vostre lloc (podeu utilitzar la forma http://www.elmeulloc/com o simplement indicar el número d’un article d’aquest lloc.',
	'barre_note' => 'Transformar en [[Nota a peu de pàgina]]',
	'barre_paragraphe' => 'Crear un paràgraf',
	'barre_quote' => '<quote>Citar un missatge</quote>',
	'bouton_changer' => 'Canviar',
	'bouton_chercher' => 'Buscar',
	'bouton_choisir' => 'Escollir',
	'bouton_deplacer' => 'Desplaçar',
	'bouton_download' => 'Descarregar',
	'bouton_enregistrer' => 'Enregistrar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la missatgeria interna',
	'bouton_radio_envoi_annonces' => 'Enviar els anuncis editorials',
	'bouton_radio_non_envoi_annonces' => 'No enviar anuncis',
	'bouton_radio_non_envoi_liste_nouveautes' => 'No enviar la llista de novetats',
	'bouton_recharger_page' => 'recarregar aquesta pàgina',
	'bouton_telecharger' => 'Baixar',
	'bouton_upload' => 'Baixar',
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'tarda',
	'cal_jour_entier' => 'dia sencer',
	'cal_matin' => 'matí',
	'cal_par_jour' => 'calendari diari',
	'cal_par_mois' => 'calendari mensual',
	'cal_par_semaine' => 'calendari setmanal',
	'choix_couleur_interface' => 'color',
	'choix_interface' => 'elecció de la interfície',
	'colonne' => 'Columna',
	'confirm_changer_statut' => 'Atenció, heu demanat canviar l’estat d’aquest element. Voleu continuar? ',
	'correcte' => 'correcte',

	// D
	'date_aujourdhui' => 'avui',
	'date_avant_jc' => 'aC',
	'date_dans' => 'en @delai@',
	'date_de_mois_1' => '@j@ de gener',
	'date_de_mois_10' => '@j@ d’octubre',
	'date_de_mois_11' => '@j@ de novembre',
	'date_de_mois_12' => '@j@ de desembre',
	'date_de_mois_2' => '@j@ de febrer',
	'date_de_mois_3' => '@j@ de març',
	'date_de_mois_4' => '@j@ d’abril',
	'date_de_mois_5' => '@j@ de maig',
	'date_de_mois_6' => '@j@ de juny',
	'date_de_mois_7' => '@j@ de juliol',
	'date_de_mois_8' => '@j@ d’agost',
	'date_de_mois_9' => '@j@ de setembre',
	'date_demain' => 'demà',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ a les @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ de @heure_debut@ fins @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ de @heure_debut@@dtabbr@ a @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ de @annee@',
	'date_fmt_mois_annee' => '@nommois@ de @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'el @nomjour@ @date@',
	'date_fmt_periode' => 'Del @date_debut@ fins @date_fin@', # RELIRE
	'date_fmt_periode_abbr' => 'Del @dtart@@date_debut@@dtabbr@ fins @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Del',
	'date_fmt_periode_to' => 'al',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'hores',
	'date_hier' => 'ahir',
	'date_il_y_a' => 'fa @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'diumenge',
	'date_jour_1_abbr' => 'dg.',
	'date_jour_1_initiale' => 'dg',
	'date_jour_2' => 'dilluns',
	'date_jour_2_abbr' => 'dl.',
	'date_jour_2_initiale' => 'dl',
	'date_jour_3' => 'dimarts',
	'date_jour_3_abbr' => 'dt.',
	'date_jour_3_initiale' => 'dt',
	'date_jour_4' => 'dimecres',
	'date_jour_4_abbr' => 'dc.',
	'date_jour_4_initiale' => 'dc',
	'date_jour_5' => 'dijous',
	'date_jour_5_abbr' => 'dj.',
	'date_jour_5_initiale' => 'dj',
	'date_jour_6' => 'divendres',
	'date_jour_6_abbr' => 'dv.',
	'date_jour_6_initiale' => 'dv',
	'date_jour_7' => 'dissabte',
	'date_jour_7_abbr' => 'ds.',
	'date_jour_7_initiale' => 'ds',
	'date_jours' => 'dies',
	'date_minutes' => 'minuts',
	'date_mois' => 'mes',
	'date_mois_1' => 'gener',
	'date_mois_10' => 'octubre',
	'date_mois_10_abbr' => 'oct.',
	'date_mois_11' => 'novembre',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'desembre',
	'date_mois_12_abbr' => 'des.',
	'date_mois_1_abbr' => 'gen.',
	'date_mois_2' => 'febrer',
	'date_mois_2_abbr' => 'febr.',
	'date_mois_3' => 'març',
	'date_mois_3_abbr' => 'març',
	'date_mois_4' => 'abril',
	'date_mois_4_abbr' => 'abr.',
	'date_mois_5' => 'maig',
	'date_mois_5_abbr' => 'maig',
	'date_mois_6' => 'juny',
	'date_mois_6_abbr' => 'juny',
	'date_mois_7' => 'juliol',
	'date_mois_7_abbr' => 'jul.',
	'date_mois_8' => 'agost',
	'date_mois_8_abbr' => 'agost',
	'date_mois_9' => 'setembre',
	'date_mois_9_abbr' => 'set.',
	'date_saison_1' => 'hivern',
	'date_saison_2' => 'primavera',
	'date_saison_3' => 'estiu',
	'date_saison_4' => 'tardor',
	'date_secondes' => 'segons',
	'date_semaines' => 'setmanes',
	'date_un_mois' => 'mes',
	'date_une_heure' => 'hora',
	'date_une_minute' => 'minut',
	'date_une_seconde' => 'segon',
	'date_une_semaine' => 'setmana',
	'dirs_commencer' => 'per començar realment la instal·lació',
	'dirs_preliminaire' => 'Preliminar: <b>Regular els drets d’accés</b>',
	'dirs_probleme_droits' => 'Problema de drets d’accés',
	'dirs_repertoires_absents' => '<p><b>No s’han trobat els següents directoris: </b></p><ul>@bad_dirs@</ul>  <p>És probable que la causa sigui un problema d’escriptura de les majúscules o les minúscules.
  Verifiqueu que les minúscules i les majúscules d’aquests directoris coincideixin exactament amb el que es mostra més amunt; si aquest no és el cas, canvieu el nom dels directoris amb l’ajuda del vostre programa FTP per tal de corregir l’error.</p>
  <p>Un cop feta aquesta manipulació, podreu ',
	'dirs_repertoires_suivants' => '<p><b>Els següents directoris no són accessibles a l’escriptura:</b></p> <ul>@bad_dirs@</ul>
  <p>Per solucionar-ho, feu servir el vostre client FTP per tal de regular els drets d’accés de cadascun d’aquests directoris. El procediment s’explica detalladament a la guia d’instal·lació.</p>
  <p>Un cop feta aquesta manipulació, podreu ',
	'double_occurrence' => 'Doble instància de @balise@ ',

	// E
	'en_cours' => 'en curs',
	'envoi_via_le_site' => 'Enviament per mitjà del lloc Web',
	'erreur' => 'Error',
	'erreur_balise_non_fermee' => 'última etiqueta sense tancar:',
	'erreur_technique_ajaxform' => 'Ooops. Una errada inesperada ha impedit enviar el formulari. Pot tornar a intentar-ho.',
	'erreur_technique_enregistrement_impossible' => 'Una errada tècnica ha impedit l’enregistrament.',
	'erreur_texte' => 'error(s)',
	'etape' => 'Etapa',

	// F
	'fichier_introuvable' => 'Fitxer @fichier@ introbable', # MODIF
	'form_auteur_confirmation' => 'Confirmeu el vostre correu electrònic',
	'form_auteur_email_modifie' => 'El vostre correu electrònic s’ha modificat.',
	'form_auteur_envoi_mail_confirmation' => 'Us acabem d’enviar un correu electrònic de confirmació a @email@. Per validar la vostra adreça de correu electrònic, haureu de visitar l’adreça Web esmentada en aquest correu.',
	'form_auteur_mail_confirmation' => 'Bon dia,

Heu demanat canviar la vostra adreça electrònica.
Per confirmar la nova adreça, només heu de connectar-vos a l’adreça que hi ha més avall (de no fer-ho així, la vostra petició s’ignorarà):

    @url@
',
	'form_deja_inscrit' => 'Ja estàs inscrit/a.',
	'form_email_non_valide' => 'La seva adreça electrònica no ha estat validada.',
	'form_forum_access_refuse' => 'No teniu accés a aquest lloc.',
	'form_forum_bonjour' => 'Bon dia @nom@,',
	'form_forum_confirmer_email' => 'Per confirmar la vostra adreça de correu electrònic, dirigiu-vos a aquesta adreça: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Aquesta adreça electrònica ja ha estat enregistrada, podeu utilitzar la vostra contrasenya habitual. ',
	'form_forum_identifiant_mail' => 'La identificació us ha estat enviada per correu electrònic. ',
	'form_forum_identifiants' => 'Identificadors personals',
	'form_forum_indiquer_nom_email' => 'Indiqueu aquí el vostre nom i la vostra adreça electrònica. L’identificador personal us serà enviat, ben aviat, per correu electrònic.',
	'form_forum_login' => 'Usuari:',
	'form_forum_message_auto' => '(això és un missatge automàtic)',
	'form_forum_pass' => 'contrasenya:',
	'form_forum_probleme_mail' => 'Problema d’adreça electrònica: l’identificador no es pot enviar.',
	'form_forum_voici1' => 'Aquí teniu els identificadors per poder participar als fòrums del lloc Web "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Aquests són els identificadors per poder proposar articles en aquest lloc
"@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Indiqueu la vostra adreça electrònica.',
	'form_indiquer_nom' => 'Indiqueu el vostre nom.',
	'form_indiquer_nom_site' => 'Indiqueu el nom del vostre lloc.',
	'form_pet_deja_enregistre' => 'Aquest lloc ja està registrat.',
	'form_pet_signature_pasprise' => 'La seva signatura no s’ha tingut en compte.',
	'form_prop_confirmer_envoi' => 'Confirmar l’enviament',
	'form_prop_description' => 'Descripció/commentari',
	'form_prop_enregistre' => 'La seva proposta ha estat registrada, apareixerà en línia després de ser validada pels responsables d’aquest lloc.',
	'form_prop_envoyer' => 'Enviar un missatge',
	'form_prop_indiquer_email' => 'Indiqueu una adreça electrònica vàlida',
	'form_prop_indiquer_nom_site' => 'Indiqueu el nom del lloc.',
	'form_prop_indiquer_sujet' => 'Indiqueu un assumpte',
	'form_prop_message_envoye' => 'Missatge enviat',
	'form_prop_non_enregistre' => 'La seva proposta no ha estat registrada.',
	'form_prop_sujet' => 'Assumpte:',
	'form_prop_url_site' => 'Adreça URL del lloc',
	'forum_non_inscrit' => 'No esteu inscrit o bé l’adreça o la contrasenya són errònies. ',
	'forum_par_auteur' => 'per @auteur@',
	'forum_titre_erreur' => 'Error...',

	// I
	'ical_texte_rss_articles' => 'El fitxer «backend» dels articles d’aquest lloc es troba a l’adreça:',
	'ical_texte_rss_articles2' => 'Podeu igualment obtenir fitxers «backend» pels articles de cada secció d’aquest lloc:',
	'ical_texte_rss_breves' => 'Existeix també un fitxer que conté les breus del lloc. Especificant el número de secció, es poden obtenir únicament les breus d’aquesta.',
	'icone_a_suivre' => 'Novetats',
	'icone_admin_site' => 'Administració del lloc',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Ajuda',
	'icone_articles' => 'Articles',
	'icone_auteurs' => 'Autors/es',
	'icone_brouteur' => 'Navegació ràpida',
	'icone_configuration_site' => 'Configuració',
	'icone_configurer_site' => 'Configurar el vostre lloc',
	'icone_creer_nouvel_auteur' => 'Crear un nou autor o autora',
	'icone_creer_rubrique' => 'Crear una secció',
	'icone_creer_sous_rubrique' => 'Crear una subsecció',
	'icone_deconnecter' => 'Desconnectar-se',
	'icone_discussions' => 'Discussions',
	'icone_doc_rubrique' => 'Documents de les seccions',
	'icone_ecrire_article' => 'Escriure un nou article',
	'icone_edition_site' => 'Edició',
	'icone_gestion_langues' => 'Gestió de les llengües',
	'icone_informations_personnelles' => 'Informacions personals',
	'icone_interface_complet' => 'interfície completa',
	'icone_interface_simple' => 'Interfície simple',
	'icone_maintenance_site' => 'Manteniment del lloc',
	'icone_messagerie_personnelle' => 'Missatgeria personal',
	'icone_repartition_debut' => 'Mostrar la distribució des del començament',
	'icone_rubriques' => 'Seccions',
	'icone_sauver_site' => 'Còpia de seguretat del lloc',
	'icone_site_entier' => 'Tot el lloc',
	'icone_sites_references' => 'Llocs referenciats',
	'icone_statistiques' => 'Estadístiques del lloc',
	'icone_suivi_activite' => 'Seguir la vida del lloc',
	'icone_suivi_actualite' => 'Evolució del lloc',
	'icone_suivi_pettions' => 'Seguir/gestionar les peticions',
	'icone_suivi_revisions' => 'Modificacions dels articles ',
	'icone_supprimer_document' => 'Suprimir aquest document',
	'icone_supprimer_image' => 'Suprimir aquesta imatge',
	'icone_tous_articles' => 'Tots els seus articles',
	'icone_tous_auteur' => 'Tots els autors i autores',
	'icone_tous_visiteur' => 'Tots els visitants',
	'icone_visiter_site' => 'Veure el lloc públic',
	'icone_voir_en_ligne' => 'Visualitzar en línia',
	'img_indisponible' => 'imatge no disponible',
	'impossible' => 'impossible',
	'info_a_suivre' => 'NOVETATS»',
	'info_acces_interdit' => 'Accés prohibit',
	'info_acces_refuse' => 'Accés refusat',
	'info_action' => 'Acció: @action@',
	'info_administrer_rubriques' => 'Podeu administrat aquesta secció i les seves subseccions',
	'info_adresse_non_indiquee' => 'No heu indicat cap adreça per provar!',
	'info_aide' => 'AJUDA:',
	'info_ajouter_mot' => 'Afegir aquesta paraula',
	'info_annonce' => 'ANUNCI',
	'info_annonces_generales' => 'Avisos generals:',
	'info_article_propose' => 'Article proposat',
	'info_article_publie' => 'Article publicat',
	'info_article_redaction' => 'Article en curs de redacció',
	'info_article_refuse' => 'Article rebutjat',
	'info_article_supprime' => 'Article suprimit',
	'info_articles' => 'Articles',
	'info_articles_a_valider' => 'Articles per validar',
	'info_articles_nb' => '@nb@ articles',
	'info_articles_proposes' => 'Articles proposats',
	'info_articles_un' => '1 article',
	'info_auteurs_nombre' => 'autor(s)/es:',
	'info_authentification_ftp' => 'Autenticació (per FTP).',
	'info_breves_2' => 'breus',
	'info_breves_nb' => '@nb@ breus',
	'info_breves_un' => '1 breu',
	'info_connexion_refusee' => 'Connexió denegada',
	'info_contact_developpeur' => 'Contacteu amb un desenvolupador.',
	'info_contenance' => 'Aquest lloc conté:',
	'info_contribution' => 'contribucions',
	'info_copyright' => '@spip@ és programari lliure distribuït @lien_gpl@.',
	'info_copyright_doc' => 'Per a més informació, veure el lloc <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'sota llicència GPL',
	'info_cours_edition' => 'Els vostres articles en procés de redacció', # MODIF
	'info_creer_repertoire' => 'Creeu un fitxer o un directori anomenat:',
	'info_creer_repertoire_2' => 'a l’interior del subdirectori <b>@repertoire@</b>, després:',
	'info_creer_vignette' => 'creació automàtica de la miniatura',
	'info_creerdansrubrique_non_autorise' => 'No té autorització per a crear contingut dins d’aquesta secció',
	'info_deplier' => 'Desplegar',
	'info_descriptif_nombre' => 'descripció(ns):',
	'info_description' => 'Descripció:',
	'info_description_2' => 'Descripció:',
	'info_dimension' => 'Mida:',
	'info_documents_nb' => '@nb@ documents',
	'info_documents_un' => '1 document',
	'info_ecire_message_prive' => 'Escriure un missatge privat',
	'info_email_invalide' => 'L’adreça electrònica no és vàlida.',
	'info_en_cours_validation' => 'Articles en procés de redacció',
	'info_en_ligne' => 'Actualment en línia:',
	'info_envoyer_message_prive' => 'Enviar un missatge privat a aquest/a autor/a',
	'info_erreur_requete' => 'Error en la petició:',
	'info_erreur_squelette2' => 'No hi ha cap esquelet <b>@fichier@</b> que estigui disponible...',
	'info_erreur_systeme' => 'Error del sistema (errno @errsys@)',
	'info_erreur_systeme2' => 'És probable que el disc dur estigui ple, o la base de dades feta malbé.<br />
<span style="color:red;">Proveu de <a href=\'@script@\'>reparar la base</a>, o contacteu amb el vostre hostatjador.</span>',
	'info_fini' => 'S’ha acabat! ',
	'info_format_image' => 'Formats d’imatges que es poden fer servir per crear vinyetes: @gd_formats@.',
	'info_format_non_defini' => 'format no definit',
	'info_grand_ecran' => 'Pantalla gran',
	'info_image_aide' => 'AJUDA',
	'info_image_process_titre' => 'Mètode de fabricació de miniatures',
	'info_impossible_lire_page' => '<b>Error!</b> Impossible llegir la pàgina <tt><html>@test_proxy@</html></tt> per mitjà del proxy',
	'info_installation_systeme_publication' => 'Instal·lació del sistema de publicació...',
	'info_installer_documents' => 'Podeu instal·lar automàticament tots els documents que hi ha dins la carpeta @upload@.',
	'info_installer_ftp' => 'En tan que administrador, podeu instal·lar (per FTP) els fitxers a la carpeta @upload@ per a continuació seleccionar-los directament aquí.',
	'info_installer_images' => 'Podeu instal·lar imatges amb els formats JPEG, GIF i PNG.',
	'info_installer_images_dossier' => 'Instal·lar imatges a la carpeta @upload@ per poder-les seleccionar aquí.',
	'info_interface_complete' => 'interfície completa',
	'info_interface_simple' => 'Interfície simple',
	'info_joindre_document_article' => 'Podeu adjuntar a aquest article documents del tipus ',
	'info_joindre_document_rubrique' => 'Podeu adjuntar en aquesta secció documents del tipus ',
	'info_joindre_documents_article' => 'Poden adjuntar al vostre article documents del tipus:',
	'info_l_article' => 'l’article',
	'info_la_breve' => 'la breu',
	'info_la_rubrique' => 'la secció',
	'info_langue_principale' => 'Idioma principal del lloc',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ píxels',
	'info_les_auteurs_1' => 'per @les_auteurs@',
	'info_logo_format_interdit' => 'Només els logotips amb formats @formats@ estan autoritzats.',
	'info_logo_max_poids' => 'Els logotips han de fer obligatòriament menys de @maxi@ (aquest fitxer fa @actuel@).',
	'info_mail_fournisseur' => 'elteu@proveidor.com',
	'info_message_2' => 'MISSATGE',
	'info_message_supprime' => 'MISSATGE SUPRIMIT',
	'info_messages_nb' => '@nb@ missatges',
	'info_messages_un' => '1 missatge',
	'info_mise_en_ligne' => 'Data de publicació:',
	'info_modification_parametres_securite' => 'modificacions dels paràmetres de seguretat',
	'info_mois_courant' => 'Durant aquest mes:',
	'info_mot_cle_ajoute' => 'La paraula clau següent ha estat afegida',
	'info_multi_herit' => 'Idioma per defecte',
	'info_multi_langues_soulignees' => 'Les <u>llengües subratllades</u> es beneficien d’una traducció de tots els textos de la interfície. Si seleccioneu aquestes llengües, molts elements del lloc públic (dates, formularis) es traduiran automàticament. En les llengües no subratllades, aquests elements es mostraran en la llengua principal del lloc.',
	'info_multilinguisme' => 'Multilingüisme',
	'info_nom_non_utilisateurs_connectes' => 'El vostre nom no apareix a la llista d’usuaris/àries connectats/des.',
	'info_nom_utilisateurs_connectes' => 'El vostre nom apareix a la llista dels usuaris connectats.',
	'info_nombre_en_ligne' => 'Actualment en línia:',
	'info_non_resultat' => 'Cap resultat per "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'No feu servir la missatgeria interna d’aquest lloc.',
	'info_nouveau_message' => 'TENIU UN NOU MISSATGE',
	'info_nouveaux_messages' => 'TENIU @total_messages@ NOUS MISSATGES',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Aquesta informació és obligatòria',
	'info_pense_bete' => 'RECORDATORI',
	'info_petit_ecran' => 'Pantalla petita',
	'info_petition_close' => 'Petició tancada',
	'info_pixels' => 'pixels',
	'info_plusieurs_mots_trouves' => 'S’ha trobat diverses paraules clau per "@cherche_mot@":',
	'info_portfolio_automatique' => 'Carpeta automàtica:',
	'info_premier_resultat' => '[@debut_limit@ primers resultats sobre @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primers resultats sobre @total@]',
	'info_propose_1' => '[@nom_site_spip@] Proposa: @titre@',
	'info_propose_2' => 'Article proposat
----------------',
	'info_propose_3' => 'L’article "@titre@" està proposat per a ser publicat.',
	'info_propose_4' => 'Esteu convidats a consultar-lo i a donar la vostra opinió',
	'info_propose_5' => 'al fòrum que hi enllaça. El trobareu disponible a l’adreça:',
	'info_publie_01' => 'L’article "@titre@" ha estat validat per @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICAT: @titre@',
	'info_publie_2' => 'Article publicat
----------------',
	'info_rechercher' => 'Cercar',
	'info_rechercher_02' => 'Cercar:',
	'info_remplacer_vignette' => 'Substituir la icona per defecte per un logotip personalitzat:',
	'info_rubriques_nb' => '@nb@ seccions',
	'info_rubriques_un' => '1 secció',
	'info_sans_titre_2' => 'sense títol',
	'info_selectionner_fichier' => 'Podeu seleccionar un fitxer de la carpeta @upload@',
	'info_selectionner_fichier_2' => 'Seleccionar un fitxer:',
	'info_sites_nb' => '@nb@ llocs',
	'info_sites_un' => '1 lloc',
	'info_supprimer_vignette' => 'suprimir la icona',
	'info_symbole_bleu' => 'El símbol <b>blau</b> indica un <b>recordatori</b>: és a dir un missatge per a ús personal.',
	'info_symbole_jaune' => 'El símbol <b>groc</b> indica un <b>avís a tots els redactors</b> : modificable per tots els administradors i visible per tots els redactors.',
	'info_symbole_vert' => 'El símbol <b>vert</b> indica els <b>missatges intercanviats amb altres usuaris</b> del lloc Web.',
	'info_telecharger_nouveau_logo' => 'Carregar un nou logotip:',
	'info_telecharger_ordinateur' => 'Carregar des del vostre ordinador:',
	'info_tous_resultats_enregistres' => '[tots els resultats són registrats]',
	'info_tout_afficher' => 'Mostrar-ho tot',
	'info_travaux_texte' => 'Aquest lloc encara no està configurat. Torneu més endavant...',
	'info_travaux_titre' => 'Lloc en construcció',
	'info_trop_resultat' => 'Massa resultats per "@cherche_mot@"; si voleu afinar la cerca.',
	'info_utilisation_messagerie_interne' => 'Utilitzeu la missatgeria interna d’aquest lloc.',
	'info_valider_lien' => 'validar aquest enllaç',
	'info_verifier_image' => ', voleu verificar que les vostres imatges han estat transferides correctament.',
	'info_vignette_defaut' => 'Icona per defecte',
	'info_vignette_personnalisee' => 'Icona personalitzada',
	'info_visite' => 'visita:',
	'info_vos_rendez_vous' => 'Les vostres cites',
	'infos_vos_pense_bete' => 'Els vostres recordatoris',

	// L
	'label_ajout_id_rapide' => 'Afegit ràpid',
	'label_poids_fichier' => 'Mida',
	'lien_afficher_icones_seuls' => 'Mostrar només les icones',
	'lien_afficher_texte_icones' => 'Mostrar les icones i el text',
	'lien_afficher_texte_seul' => 'Mostrar només el text',
	'lien_liberer' => 'alliberar',
	'lien_liberer_tous' => 'alliberar aquests articles',
	'lien_nouvea_pense_bete' => 'NOU RECORDATORI',
	'lien_nouveau_message' => 'NOU MISSATGE',
	'lien_nouvelle_annonce' => 'NOU ANUNCI',
	'lien_petitions' => 'PETICIÓ',
	'lien_popularite' => 'popularitat: @popularite@%',
	'lien_racine_site' => 'ARREL DEL LLOC',
	'lien_reessayer' => 'Reintentar',
	'lien_repondre_message' => 'Respondre a aquest missatge',
	'lien_supprimer' => 'suprimir',
	'lien_tout_afficher' => 'Mostrar-ho tot',
	'lien_visite_site' => 'visitar aquest lloc',
	'lien_visites' => '@visites@ visites',
	'lien_voir_auteur' => 'Veure aquest autor',
	'ligne' => 'Línia',
	'login' => 'Connexió',
	'login_acces_prive' => 'accés a l’espai privat',
	'login_autre_identifiant' => 'connectar-se amb un altre nom d’usuari/ària',
	'login_cookie_accepte' => 'Configura el teu navegador perquè les accepti (al menys per aquest lloc).',
	'login_cookie_oblige' => 'Per identificar-vos d’una manera segura en aquest lloc, heu d’acceptar les galetes.',
	'login_deconnexion_ok' => 'Desconnexió efectuada.',
	'login_erreur_pass' => 'Error de contrasenya.',
	'login_espace_prive' => 'espai privat',
	'login_identifiant_inconnu' => 'L’usuari « @login@ » és desconegut',
	'login_login' => 'Login:',
	'login_login2' => 'Login (identificador de connexió) o adreça de correu electrònic:',
	'login_login_pass_incorrect' => '(Login ou contrasenya incorretecte.)',
	'login_motpasseoublie' => 'contrasenya oblidada?',
	'login_non_securise' => 'Atenció, aquest formulari no és segur. Si no voleu que la vostra contrasenya pugui ser interceptada a la xarxa, activeu Javascript al vostre navegador i ',
	'login_nouvelle_tentative' => 'Nou intent',
	'login_par_ici' => 'Esteu registrats... per aquí...',
	'login_pass2' => 'Contrasenya:',
	'login_preferez_refuser' => '<b>Si preferiu refusar les galetes</b>, un altre mètode de connexió (menys segur) és a la vostra disposició :',
	'login_recharger' => 'actualitzar aquesta pàgina',
	'login_rester_identifie' => 'Continuar identificat alguns dies', # MODIF
	'login_retour_public' => 'Tornar al lloc públic',
	'login_retour_site' => 'Tornar al lloc públic',
	'login_retoursitepublic' => 'tornar al lloc públic',
	'login_securise' => 'Inici de sessió segur',
	'login_sinscrire' => 'inscriure’s',
	'login_test_navigateur' => 'prova de navegador/tornar a connectar',
	'login_verifiez_navigateur' => '(Verifiqueu no obstant que el vostre navegador no ha memoritzat la contrasenya...)',

	// M
	'masquer_colonne' => 'Ocultar aquesta columna',
	'masquer_trad' => 'amagar les traduccions',
	'module_fichiers_langues' => 'Fitxers de llengua',

	// N
	'navigateur_pas_redirige' => 'Si el vostre navegador no és redirigit, cliqueu aquí per continuar.',
	'numero' => 'Número',

	// O
	'occurence' => 'Instància',
	'onglet_affacer_base' => 'Suprimir la base de dades',
	'onglet_auteur' => 'L’autor/a',
	'onglet_contenu_site' => 'Contingut del lloc',
	'onglet_evolution_visite_mod' => 'Evolució',
	'onglet_fonctions_avances' => 'Funcions avançades',
	'onglet_informations_personnelles' => 'Informacions personals',
	'onglet_interactivite' => 'Interactivitat',
	'onglet_messagerie' => 'Missatgeria',
	'onglet_repartition_rubrique' => 'Distribució per seccions',
	'onglet_save_restaur_base' => 'Còpia de seguretat/restaurar base de dades',
	'onglet_vider_cache' => 'Buidar la memòria cau',

	// P
	'pass_choix_pass' => 'Escolliu la vostra nova contrasenya:',
	'pass_erreur' => 'Error',
	'pass_erreur_acces_refuse' => '<b>Error:</b> ja no teniu accés en aquest lloc.',
	'pass_erreur_code_inconnu' => '<b>Error:</b> aquest codi no correspon a cap dels visitants que tenen accés a aquest lloc.',
	'pass_erreur_non_enregistre' => '<b>Error:</b> l’adreça <tt>@email_oubli@</tt> no està registrada en aquest lloc.',
	'pass_erreur_non_valide' => '<b>Error:</b> aquest correu electrònic <tt>@email_oubli@</tt> no és vàlid!',
	'pass_erreur_probleme_technique' => '<b>Error:</b> per culpa d’un problema tècnic, el correu electrònic no s’ha pogut enviar.',
	'pass_espace_prive_bla' => 'L’espai privat d’aquest lloc està obert als visitants, un cop s’han inscrit. Una vegada registrats, podeu consultar els articles en procés de redacció, proposar articles i participar en tots els fòrums. ',
	'pass_forum_bla' => 'Heu demanat d’intervenir en un fòrum reservat als visitants registrats.',
	'pass_indiquez_cidessous' => 'Indiqueu a sota l’adreça electrònica amb la que us heu registrat anteriorment. Rebreu un correu electrònic indicant-vos els passos a seguir per recuperar el vostre accés. ',
	'pass_mail_passcookie' => '(aquest és un missatge automàtic)
Per recuperar el vostre accés al lloc
@nom_site_spip@ (@adresse_site@)

Aneu a l’adreça següent:

    @sendcookie@

Llavors podreu entrar una nova contrasenya
i tornar-vos a connectar al lloc.

',
	'pass_mot_oublie' => 'Contrasenya oblidada',
	'pass_nouveau_enregistre' => 'La vostra nova contrasenya ha estat registrada.',
	'pass_nouveau_pass' => 'Nova contrasenya',
	'pass_ok' => 'D’acord',
	'pass_oubli_mot' => 'Oblit de la contrasenya',
	'pass_procedure_changer' => 'Per canviar la contrasenya, hem de verificar primerament la vostra identitat. Per això, indiqueu-nos el correu electrònic associat al vostre compte.', # MODIF
	'pass_quitter_fenetre' => 'Tancar aquesta finestra',
	'pass_rappel_login' => 'Recordatori: la vostra identificació (usuari) és " @login@".',
	'pass_recevoir_mail' => 'Voleu rebre un correu electrònic indicant com recuperar l’accés al lloc.', # MODIF
	'pass_retour_public' => 'Tornar al lloc públic',
	'pass_rien_a_faire_ici' => 'Res a fer aquí.',
	'pass_vousinscrire' => 'Incriure’s a aquesta web',
	'precedent' => 'anterior',
	'previsualisation' => 'Previsualització',
	'previsualiser' => 'Visualització prèvia',

	// R
	'retour' => 'Retorn',

	// S
	'spip_conforme_dtd' => 'SPIP considera aquest document conforme al seu DOCTYPE :',
	'squelette' => 'esquelet',
	'squelette_inclus_ligne' => 'esquelet inclòs, línia',
	'squelette_ligne' => 'esquelet, línia',
	'stats_visites_et_popularite' => '@visites@ visites; popularitat: @popularite@',
	'suivant' => 'següent',

	// T
	'taille_ko' => '@taille@ kB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Quan estareu familiaritzats amb la interfície, podreu clicar a «',
	'texte_actualite_site_2' => 'interfície completa',
	'texte_actualite_site_3' => '" per obrir més possibilitats.',
	'texte_creation_automatique_vignette' => 'La creació automàtica d’icones de previsualització està activada amb els formats @gd_formats@, estaran acompanyades d’una icona com a  màxim de @taille_preview@ pixels.',
	'texte_documents_associes' => 'Els documents següents estan associats a l’article, però no han estat directament inclosos. Segons la compaginació del lloc públic, es podran mostrar com a documents adjunts.',
	'texte_erreur_mise_niveau_base' => 'Error de la base de dades durant la seva actualització.
 La imatge <b>@fichier@</b> no ha passat (article @id_article@).
  Anoteu aquesta referència, proveu altre cop
 l’actualització i, finalment, verifiqueu que les imatges
 apareixen sempre als articles.',
	'texte_erreur_visiteur' => 'Heu intentat accedir a l’espai privat amb un login que no li permet.',
	'texte_inc_auth_1' => 'Us heu identificat amb el nom d’usuari <b>@auth_login@</b>, però aquest no existeix/ja no existeix a la base de dades.
  Proveu de ',
	'texte_inc_auth_2' => 'reconnectar',
	'texte_inc_auth_3' => ', després de tancar i tornar a arrencar el vostre ordinador.',
	'texte_inc_config' => 'Les modificacions efectuades en aquestes pàgines influeixen notablement en el
 funcionament del vostre lloc Web. Us recomanem no tocar res fins que no estigueu familiaritzats amb el funcionament del sistema SPIP. <br /><br /><b> En general
,  es molt aconsellable
 deixar la càrrega d’aquestes pàgines al webmestre principal del vostre lloc Web.</b>',
	'texte_inc_meta_1' => 'El sistema ha trobat un error durant l’escriptura del fitxer <code>@fichier@</code>.Si us plau, ja que sou l’administrador/a del lloc web,',
	'texte_inc_meta_2' => 'verifiqueu els drets d’escriptura',
	'texte_inc_meta_3' => 'del directori <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en curs de redacció',
	'texte_statut_poubelle' => 'a la paperera',
	'texte_statut_propose_evaluation' => 'proposat per a l’avaluació',
	'texte_statut_publie' => 'publicat en línia',
	'texte_statut_refuse' => 'refusat',
	'titre_ajouter_mot_cle' => 'AFEGIR UNA PARAULA CLAU:',
	'titre_cadre_raccourcis' => 'DRECERES',
	'titre_changer_couleur_interface' => 'Canviar el color de l’interficie',
	'titre_image_admin_article' => 'Vosté pot administrar aquest article',
	'titre_image_administrateur' => 'Administrador/a',
	'titre_image_aide' => 'De l’ajuda sobre aquest element',
	'titre_image_auteur_supprime' => 'Autor/a suprimit/da',
	'titre_image_redacteur' => 'Redactor/a sense accés',
	'titre_image_redacteur_02' => 'Redactor/a',
	'titre_image_selecteur' => 'Afegir la llista',
	'titre_image_visiteur' => 'Visitant',
	'titre_joindre_document' => 'INTRODUIR UN DOCUMENT',
	'titre_mots_cles' => 'PARAULES CLAU',
	'titre_probleme_technique' => 'Atenció: un problema tècnic (servidor SQL) impedeix l’accés a aquesta part de la Web. Gràcies per la vostra comprensió.',
	'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS D’AQUESTA SECCIÓ',
	'titre_signatures_attente' => 'Signatures esperant ser validades',
	'titre_signatures_confirmees' => 'Signatures confirmades',
	'titre_statistiques' => 'Estadistiques de la pàgina',
	'titre_titre_document' => 'Títol del document:',
	'todo' => 'pròximament  ',
	'trad_definir_reference' => 'Triar "@titre@" com referència de les traduccions',
	'trad_reference' => '(article de referència)',

	// Z
	'zbug_balise_b_aval' => ' : l’etiqueta B ha d’anar abans',
	'zbug_balise_inexistante' => 'etiqueta @balise@ mal declarada per a @from@ ',
	'zbug_balise_sans_argument' => 'Argument que falta a l’etiqueta @balise@',
	'zbug_boucle' => 'bucle',
	'zbug_boucle_recursive_undef' => 'Bucle recurrent no definit: @nom@',
	'zbug_calcul' => 'càlcul',
	'zbug_champ_hors_boucle' => 'Camp @champ@ fora de bucle',
	'zbug_champ_hors_motif' => 'Camp @champ@ fora d’un context @motif@',
	'zbug_code' => 'codi',
	'zbug_critere_inconnu' => 'Criteri desconegut @critere@',
	'zbug_distant_interdit' => 'Prohibit amb dades externes',
	'zbug_doublon_table_sans_cle_primaire' => 'Doublons en una taula sense clau primària atòmica',
	'zbug_doublon_table_sans_index' => 'Doublons em una taula sense índex',
	'zbug_erreur_boucle_double' => 'Doble definició del bucle @id@ ',
	'zbug_erreur_boucle_fermant' => 'Bucle @id@ no tancat',
	'zbug_erreur_boucle_syntaxe' => 'Sintaxi incorrecte del bucle @id@',
	'zbug_erreur_compilation' => 'Error de compilació',
	'zbug_erreur_execution_page' => 'Error d’execució',
	'zbug_erreur_filtre' => 'Filtre @filtre@ no definit',
	'zbug_erreur_meme_parent' => 'El criteri {meme_parent} només s’aplica als bucles (FORUMS) o (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Error(s) en l’esquelet',
	'zbug_hors_compilation' => 'Sense Compilació',
	'zbug_info_erreur_squelette' => 'Error en el lloc Web',
	'zbug_inversion_ordre_inexistant' => 'Inversió d’un ordre inexistent',
	'zbug_pagination_sans_critere' => 'Etiqueta #PAGINATION sense criteri {paginació} o  fet servir a dins d’un bucle recursiu.',
	'zbug_parametres_inclus_incorrects' => 'Paràmetre d’inclusió incorrecte: @param@',
	'zbug_profile' => 'Temps de càlcul : @time@',
	'zbug_resultat' => 'resultat',
	'zbug_serveur_indefini' => 'Servidor SQL sense definir',
	'zbug_statistiques' => 'Estadístiques de peticions SQL classificades per durada',
	'zbug_table_inconnue' => 'Taula SQL « @table@ » desconeguda',
	'zxml_connus_attributs' => 'atributs conneguts',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atribut desconegut',
	'zxml_inconnu_balise' => 'etiqueta desconeguda',
	'zxml_inconnu_entite' => 'entitat desconeguda',
	'zxml_inconnu_id' => 'ID desconegut',
	'zxml_mais_de' => 'però de',
	'zxml_non_conforme' => 'no conforme al motiu',
	'zxml_non_fils' => 'no és un fill de',
	'zxml_nonvide_balise' => 'etiqueta no buida',
	'zxml_obligatoire_attribut' => 'atribut obligatori però absent a dins de',
	'zxml_succession_fils_incorrecte' => 'herència de fills incorrecte',
	'zxml_survoler' => 'passar el ratolí per sobre per veure els correctes',
	'zxml_valeur_attribut' => 'valor de l’atribut',
	'zxml_vide_balise' => 'etiqueta buida',
	'zxml_vu' => 'vist abans'
);
